==> jc-1.4.0.tar.gz: java/security/cert/CRL.c <==
// public abstract class java.security.cert.CRL

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 968d6f530411e76e java_security_cert_CRL
// @dep_class c98c8192da849b07 java_security_cert_Certificate

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_security_cert_CRL
// @dep_header java_security_cert_Certificate

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/security/cert/CRL.h"
#include "java/security/cert/Certificate.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String type
static _jc_field _jc_java_security_cert_CRL$field_info$type = {
	.name=		"type",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_security_cert_CRL$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_security_cert_CRL$object, refs[-1].java_security_cert_CRL.type),
};

// Fields
static _jc_field *const _jc_java_security_cert_CRL$fields[] = {
	&_jc_java_security_cert_CRL$field_info$type
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(java.lang.String)
//

static _jc_linenum _jc_java_security_cert_CRL$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_security_cert_CRL$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_security_cert_CRL$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_java_security_cert_CRL$type,
	.param_types=		&_jc_java_security_cert_CRL$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_security_cert_CRL$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_security_cert_CRL$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_cert_CRL, _init$c31b894660454d13);

void
_jc_java_security_cert_CRL$method$_init$c31b894660454d13(_jc_env *const env, _jc_java_security_cert_CRL$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_java_security_cert_CRL$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(66);				// 0
	_JC_REF_FIELD(env, r0, java_security_cert_CRL, type) = r1;
	_JC_LINE_NUMBER(67);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.String getType()
//

static _jc_linenum _jc_java_security_cert_CRL$linenum_table$getType$1756580bdd350fe6[];

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$getType$1756580bdd350fe6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6 = {
	.name=			"getType",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_cert_CRL$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$getType$1756580bdd350fe6,
	.signature_hash=	_JC_JLONG(0x1756580bdd350fe6),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.getType$1756580bdd350fe6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_security_cert_CRL$linenum_table$getType$1756580bdd350fe6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_cert_CRL, getType$1756580bdd350fe6);

_jc_java_lang_String$object *
_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6(_jc_env *const env, _jc_java_security_cert_CRL$object *this)
{
	struct _jc_java_security_cert_CRL$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(76);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_security_cert_CRL, type);
	return r1;
}

//
// public abstract boolean isRevoked(java.security.cert.Certificate)
//

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$isRevoked$9ba1c89363dd6209[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_security_cert_CRL$param_types$isRevoked$9ba1c89363dd6209[] = {
	&_jc_java_security_cert_Certificate$type
};

_jc_method _jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209 = {
	.name=			"isRevoked",
	.signature=		"(Ljava/security/cert/Certificate;)Z",
	.class=			&_jc_java_security_cert_CRL$type,
	.param_types=		&_jc_java_security_cert_CRL$param_types$isRevoked$9ba1c89363dd6209,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$isRevoked$9ba1c89363dd6209,
	.signature_hash=	_JC_JLONG(0x9ba1c89363dd6209),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.isRevoked$9ba1c89363dd6209) / sizeof(void *),
	.num_parameters=	1,
};

jboolean
_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209(_jc_env *const env, _jc_java_security_cert_CRL$object *this, _jc_java_security_cert_Certificate$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209);
}

//
// public abstract java.lang.String toString()
//

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_cert_CRL$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object *
_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_security_cert_CRL$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_security_cert_CRL$methods[] = {
	&_jc_java_security_cert_CRL$method_info$_init$c31b894660454d13,
	&_jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6,
	&_jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209,
	&_jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_security_cert_CRL$instanceof_hash_bucket_110[] = {
	&_jc_java_security_cert_CRL$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_cert_CRL$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_security_cert_CRL$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[110]=	_jc_java_security_cert_CRL$instanceof_hash_bucket_110,
	[113]=	_jc_java_security_cert_CRL$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_security_cert_CRL$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/security/cert/Certificate",	_JC_JLONG(0xc98c8192da849b07) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_security_cert_CRL$vtype _jc_java_security_cert_CRL$type = {
    .type= {
	.name=			"java/security/cert/CRL",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x968d6f530411e76e),
		.source_file=		"CRL.java",
		.instance_size=		sizeof(_jc_java_security_cert_CRL$refs) + sizeof(_jc_java_security_cert_CRL$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_security_cert_CRL$fields) / sizeof(*_jc_java_security_cert_CRL$fields),
		.fields=		_jc_java_security_cert_CRL$fields,
		.num_methods=		sizeof(_jc_java_security_cert_CRL$methods) / sizeof(*_jc_java_security_cert_CRL$methods),
		.methods=		_jc_java_security_cert_CRL$methods,
		.instanceof_hash_table=	_jc_java_security_cert_CRL$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_security_cert_CRL$class_depends) / sizeof(*_jc_java_security_cert_CRL$class_depends),
		.class_depends=		_jc_java_security_cert_CRL$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_security_cert_CRL= {
	    .getType$1756580bdd350fe6=
		&_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6,
	    .isRevoked$9ba1c89363dd6209=
		&_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209,
	    .toString$7ea43b33b80a3070=
		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: java/security/cert/CRL.c <==
// public abstract class java.security.cert.CRL

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 968d6f530411e76e java_security_cert_CRL
// @dep_class c98c8192da849b07 java_security_cert_Certificate

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_security_cert_CRL
// @dep_header java_security_cert_Certificate

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/security/cert/CRL.h"
#include "java/security/cert/Certificate.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String type
static _jc_field _jc_java_security_cert_CRL$field_info$type = {
	.name=		"type",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_security_cert_CRL$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_security_cert_CRL$object, refs[-1].java_security_cert_CRL.type),
};

// Fields
static _jc_field *const _jc_java_security_cert_CRL$fields[] = {
	&_jc_java_security_cert_CRL$field_info$type
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(java.lang.String)
//

static _jc_linenum _jc_java_security_cert_CRL$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_security_cert_CRL$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_security_cert_CRL$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_java_security_cert_CRL$type,
	.param_types=		&_jc_java_security_cert_CRL$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_security_cert_CRL$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_security_cert_CRL$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_cert_CRL, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_java_security_cert_CRL$method$_init$c31b894660454d13(_jc_env *const env, _jc_java_security_cert_CRL$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_java_security_cert_CRL$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(66);				// 0
	_JC_REF_FIELD(env, r0, java_security_cert_CRL, type) = r1;
	_JC_LINE_NUMBER(67);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final java.lang.String getType()
//

static _jc_linenum _jc_java_security_cert_CRL$linenum_table$getType$1756580bdd350fe6[];

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$getType$1756580bdd350fe6[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6 = {
	.name=			"getType",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_cert_CRL$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$getType$1756580bdd350fe6,
	.signature_hash=	_JC_JLONG(0x1756580bdd350fe6),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.getType$1756580bdd350fe6) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_security_cert_CRL$linenum_table$getType$1756580bdd350fe6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_security_cert_CRL, getType$1756580bdd350fe6);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6(_jc_env *const env, _jc_java_security_cert_CRL$object *this)
{
	struct _jc_java_security_cert_CRL$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(76);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_security_cert_CRL, type);
	return r1;
}

//
// public abstract boolean isRevoked(java.security.cert.Certificate)
//

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$isRevoked$9ba1c89363dd6209[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_security_cert_CRL$param_types$isRevoked$9ba1c89363dd6209[] = {
	&_jc_java_security_cert_Certificate$type
};

_jc_method _jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209 = {
	.name=			"isRevoked",
	.signature=		"(Ljava/security/cert/Certificate;)Z",
	.class=			&_jc_java_security_cert_CRL$type,
	.param_types=		&_jc_java_security_cert_CRL$param_types$isRevoked$9ba1c89363dd6209,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$isRevoked$9ba1c89363dd6209,
	.signature_hash=	_JC_JLONG(0x9ba1c89363dd6209),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.isRevoked$9ba1c89363dd6209) / sizeof(void *),
	.num_parameters=	1,
};

jboolean _JC_JCNI_ATTR
_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209(_jc_env *const env, _jc_java_security_cert_CRL$object *this, _jc_java_security_cert_Certificate$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209);
}

//
// public abstract java.lang.String toString()
//

static const unsigned char _jc_java_security_cert_CRL$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_security_cert_CRL$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_security_cert_CRL$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_security_cert_CRL$vtable, java_security_cert_CRL.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
};

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_security_cert_CRL$object *this)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070);
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_security_cert_CRL$methods[] = {
	&_jc_java_security_cert_CRL$method_info$_init$c31b894660454d13,
	&_jc_java_security_cert_CRL$method_info$getType$1756580bdd350fe6,
	&_jc_java_security_cert_CRL$method_info$isRevoked$9ba1c89363dd6209,
	&_jc_java_security_cert_CRL$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_security_cert_CRL$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_security_cert_CRL$instanceof_hash_bucket_110[] = {
	&_jc_java_security_cert_CRL$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_security_cert_CRL$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_java_security_cert_CRL$instanceof_hash_bucket_101,
	[110]=	_jc_java_security_cert_CRL$instanceof_hash_bucket_110
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_security_cert_CRL$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/security/cert/Certificate",	_JC_JLONG(0xc98c8192da849b07) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_security_cert_CRL$vtype _jc_java_security_cert_CRL$type = {
    .type= {
	.name=			"java/security/cert/CRL",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x968d6f530411e76e),
		.source_file=		"CRL.java",
		.instance_size=		sizeof(_jc_java_security_cert_CRL$refs) + sizeof(_jc_java_security_cert_CRL$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_security_cert_CRL$fields) / sizeof(*_jc_java_security_cert_CRL$fields),
		.fields=		_jc_java_security_cert_CRL$fields,
		.num_methods=		sizeof(_jc_java_security_cert_CRL$methods) / sizeof(*_jc_java_security_cert_CRL$methods),
		.methods=		_jc_java_security_cert_CRL$methods,
		.instanceof_hash_table=	_jc_java_security_cert_CRL$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_security_cert_CRL$class_depends) / sizeof(*_jc_java_security_cert_CRL$class_depends),
		.class_depends=		_jc_java_security_cert_CRL$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_security_cert_CRL= {
	    .getType$1756580bdd350fe6=
		&_jc_java_security_cert_CRL$method$getType$1756580bdd350fe6,
	    .isRevoked$9ba1c89363dd6209=
		&_jc_java_security_cert_CRL$method$isRevoked$9ba1c89363dd6209,
	    .toString$7ea43b33b80a3070=
		&_jc_java_security_cert_CRL$method$toString$7ea43b33b80a3070,
	},
    }
};
